@@ -396,6 +396,22 @@ class GTK_Main(object):
             system_bus.add_signal_receiver(handler_func, 'DeviceAdded', 'org.freedesktop.Hal.Manager', None, '/org/freedesktop/Hal/Manager')
             # End Monitor connection state of BT headset
 
+            # Monitor BT headset buttons
+            system_bus = dbus.SystemBus()
+            def handle_bt_button(signal, button):
+                # See https://bugs.maemo.org/show_bug.cgi?id=8283 for details
+                if signal == 'ButtonPressed':
+                    if button == 'play-cd':
+                        player.play_pause_toggle()
+                    elif button == 'pause-cd':
+                        player.pause()
+                    elif button == 'next-song':
+                        self.seekbutton_callback(None, short_seek)
+                    elif button == 'previous-song':
+                        self.seekbutton_callback(None, -1*short_seek)
+            system_bus.add_signal_receiver(handle_bt_button, 'Condition', 'org.freedesktop.Hal.Device', None, '/org/freedesktop/Hal/devices/computer_logicaldev_input_1')
+            # End Monitor BT headset buttons
+
         player.register( 'stopped', self.on_player_stopped )
         player.register( 'playing', self.on_player_playing )
         player.register( 'paused', self.on_player_paused )
